/*****************************************************************************/
/* This code is part of the Jarol project: jarol.cs.uni-salzburg.at          */
/*                                                                           */
/* Copyright (c) 2006-2007 Bernhard Kast                                     */
/* 																			 */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.        */
/*                                                                           */
/*****************************************************************************/

package jarol;

/**
 * MessageInterface should be implemented by any class whose instances should
 * provide a <code>clone()</code>, <code>toString()</code> and <code>deepClone()</code>
 * methods.
 * 
 * <br>This is interface is the basic data type for Ports, so every class of an object put
 * into a Port must implement this interface. In order to provide compability to
 * the Exotasks system <code>deepClone()</code> was added.
 * 
 * @author Bernhard Kast
 * @version 0.1
 */

public interface MessageInterface extends Cloneable
{
	/**
	 * Clones this object.
	 * @return a clone of this object
	 * @throws CloneNotSupportedException
	 */
	public Object clone() throws CloneNotSupportedException;
	
	/**
	 * Returns a string representation of this object.
	 * @return a string representation of this object
	 */
	public String toString();
	
	/**
	 * Deepclones this object, needed for exotask compability.
	 * @return a deepclone of this object
	 */
	
	public Object deepClone();

}
