/*****************************************************************************/
/* This code is part of the Jarol project: jarol.cs.uni-salzburg.at          */
/*                                                                           */
/* Copyright (c) 2006-2007 Bernhard Kast                                     */
/* 																			 */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.        */
/*                                                                           */
/*****************************************************************************/

package jarol;

/**
 * The NavigationInterface should be implemented by any class that provides
 * navigation data and interfaces with the navigation unit.
 * 
 * <br><br>NOTE: The internal Jarol components are called interfaces, e.g., sensor interface,
 * whereas the outside components are called units, e.g., navigation unit.
 * 
 * 
 * @author Bernhard Kast
 * @version 0.1
 */

public interface NavigationInterface
{
	/**
	 * Awaits navigation data from the external navigation unit.
	 *
	 */
	public void awaitExternalNavigationData();
	
	/**
	 * Awaits Jarol Core to continue.
	 *
	 */
	
	public void awaitJarolCore();
	
	/**
	 * Reads the sensor data from Jarol Core.
	 * @return sensorData 
	 */
	
	public MessageInterface[] readSensorData();
	
	/**
	 * Forwards the sensor data to the external navigation Unit.
	 * @param sensorData
	 */
	public void forwardSensorDataToNavigationUnit(MessageInterface[] sensorData);
	
	/**
	 * Signals the external navigation unit.
	 *
	 */
	public void signalNavigationUnit();
	
	
	/**
	 * Reads the navigation data from the navigation unit.
	 * @return navigationData 
	 */
	public MessageInterface[] readNavigationData();
	
	/**
	 * Forwards the navigation data to the Jarol Core.
	 *
	 */
	public void forwardNavigationData(MessageInterface[] navigationData);
	
	/**
	 * Signals the Jarol Core.
	 *
	 */
	public void signalJarolCore();

}
