/*****************************************************************************/
/* This code is part of the Jarol project: jarol.cs.uni-salzburg.at          */
/*                                                                           */
/* Copyright (c) 2006-2007 Bernhard Kast                                     */
/* 																			 */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.        */
/*                                                                           */
/*****************************************************************************/

package jarol;




/**
 *
 * The SensorInterface should be implemented by any class whose instances should
 * be a sensor interface.
 * 
 * <br><br>NOTE: The internal Jarol components are called interfaces, e.g., sensor interface,
 * whereas the outside components are called units, e.g., navigation unit.
 * 
 *  @author Bernhard Kast
 *  @version 0.1
 */

public interface SensorInterface {
	
	/**
	 * Waits for input from the sensor unit. In an event-triggered
	 * architecture this would be an event, whereas in a time-triggered
	 * architecture this would contain a timer/wait call.
	 *
	 */
	public void awaitExternalSensor();
	
	/**
	 * Reads the sensor data.
	 * @return sensordata from the sensor
	 */
	public MessageInterface[] readSensorData();
	
	/**
	 * Forwards the sensor data to the Jarol Core.
	 *
	 */
	public void forwardToJarolCore(MessageInterface[] sensorData);
	
	/**
	 * Signals the Jarol Core to continue.
	 *
	 */
	public void signalJarolCore();
	
	

}
