/*****************************************************************************/
/* This code is part of the Jarol project: jarol.cs.uni-salzburg.at          */
/*                                                                           */
/* Copyright (c) 2006-2007 Bernhard Kast                                     */
/* 																			 */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.        */
/*                                                                           */
/*****************************************************************************/
package jarol;

import jarol.exceptions.AwaitDuringSignalingException;





/**
 * TimeTriggerInterface should be implemented by any class whose instances should
 * provide a periodic "Tick" on watchers.
 * @author Bernhard Kast
 * @version 0.1
 */
public interface TimeTriggerInterface
{
	/**
	 * Causes the calling task to be suspended until the period is finished.
	 * @throws AwaitDuringSignalingException 
	 *
	 */
	public void await() throws AwaitDuringSignalingException;
	/**
	 * Sets the period in milliseconds.
	 * @param period - The period in milliseconds.
	 */
	public void setPeriod(int period);
	/**
	 * Returns the current period.
	 * @return - The current period in milliseconds.
	 */
	public int getPeriod();
	
	/**
	 * Stops the execution of the thread.
	 *
	 */
	public void stopExecution();

}
