/*****************************************************************************/
/* This code is part of the Jarol project: jarol.cs.uni-salzburg.at          */
/*                                                                           */
/* Copyright (c) 2006-2007 Eduardo Marques                                   */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.        */
/*                                                                           */
/*****************************************************************************/
package jarol.messages;

/**
 * Message header interface. Each message group has its own way of encoding
 * the header.
 *
 * An header is seen as an object encoding at least the message id,
 * the message payload in bytes and the message timestamp.
 *
 * @author Eduardo Marques
 * @version 0.1
 */
public interface MessageHeader extends MessagePart {
  /**
   * Get the message id.
   * @return message id
   */
  public int getMessageId();
  /**
   * Get the length in bytes of the message payload
   * @return payload size
   */
  public int getPayloadSize();
  
  /**
   * Get sequence id encoded in header
   * @return sequence id in header field
   */
  public long getSequenceId();
  
  /**
   * Get the header timestamp field
   * @return header timestamp
   */
  public double getTimestamp();
  
  /**
   * Set message id.
   * @param id the message id
   */
  public void setMessageId(int id);
  
  /**
   * Set payload header field in bytes.
   * @param payload length in bytes of the message payload
   */
  public void setPayloadSize(int payload);
  
  /**
   * Set sequence id field in header.
   * @param seqid sequence id
   */
  public void setSequenceId(long seqid);
  
  /**
   * Set timestamp header field.
   * @param timestamp value of the timestamp
   */
  public void setTimestamp(double timestamp);
}
