/*****************************************************************************/
/* This code is part of the Jarol project: jarol.cs.uni-salzburg.at          */
/*                                                                           */
/* Copyright (c) 2006-2007 Eduardo Marques                                   */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.        */
/*                                                                           */
/*****************************************************************************/
package jarol.messages;
import java.io.PrintStream;

/**
 * Base interface for message parts (headers, footers and payload). 
 *
 * @author Eduardo Marques
 * @version 0.1
 */
public interface MessagePart {
  /**
   * Get serialization size.
   * @return the serialization size for the header
   */
  public int serialSize();
  /**
   * Serialization method.
   * @param buffer the output buffer
   * @throws InvalidMessageException if validation fails
   */
  public void serialize(Buffer buffer) throws InvalidMessageException;
  /**
   * De-serialization method for the header.
   * @param buffer the input buffer
   * @throws InvalidMessageException if validation fails
   */
  public void unserialize(Buffer buffer) throws InvalidMessageException;
  /**
   * Dump object in human readable form.
   * @param ps the stream for printing 
   */
  public void dump(PrintStream ps);
  /**
   * Validation method
   * @throws InvalidMessageException if the contents of this message part are invalid
   */
   public void validate() throws InvalidMessageException;
}
