/*****************************************************************************/
/* This code is part of the Jarol project: jarol.cs.uni-salzburg.at          */
/*                                                                           */
/* Copyright (c) 2006-2007 Eduardo Marques                                   */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the              */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.        */
/*                                                                           */
/*****************************************************************************/
package jarol.messages;

/**
 * Application parameterisation for message factories
 * and serialization.
 * <p>
 * This class can used to parameterize the serialization done 
 * through MessageFactory. it can be 
 * <p>
 * - The <b>timestamp counter method</b> to apply in message headers, if any
 * <p>
 * - The <b>sequence id counter</b> to apply to message headers, if any
 * <p>
 * - The <b>checksum method</b> to apply to message footers if any
 * <p>
 * This base default implementation always returns 0 for 
 * all of the above calculations and should be overriden as needed.
 * <p> 
 * All values returned are 'long' values but they may be converted 
 * to 'byte', 'short' or 'int' values according to the characteristics
 * of a particular message set. The implementation of the methods 
 * should therefore take that into consideration.
 * <p>
 * @author Eduardo Marques
 * @version 0.1
 */
public class SerializationHandle {
  /**
   * Constructor.
   */
  SerializationHandle(){

  }

  /**
   * Timestamp method. 
   * This default implementation always returns 0.0 . 
   * It should be overriden if required.
   * @return this default implementation always returns 0.
   */
  public double timestamp(){
    return 0;
  }

  /**
   * Sequence id counter method. It takes a message argument
   * to allow counters per message type (or any other 
   * message type based way).
   * This default implementation always returns 0. 
   * It should be overriden if required.
   * @param msg message argument
   * @return this default implementation always returns 0.
   */
  public long nextSequenceId(Message msg){
    return 0;
  }
  /**
   * Checksum method. 
   * This default implementation always returns 0. 
   * It should be overriden if required.
   * @param buf the source buffer for calculating the checksum
   * @param off the buffer offset for checksum calculation
   * @param len the number of bytes to consider for checksum
   * @return this default implementation always returns 0.
   */
   public long checksum(byte[] buf, int off, int len){
     return 0;
   }
}

